/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';

import AnueSearchRealtimeResult from '../AnueSearchRealtimeResult';
import defaultNotes from './AnueSearchRealtimeResult.md';

import { MOCK_HOT_SEARCH, MOCK_SEARCH_RESULT } from '../__mocks__/searchData';

const WRAPPER_STYLES = {
  width: '100vw',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  flexDirection: 'column',
};

const stories = storiesOf('AnueSearchRealtimeResult', module);

stories.addDecorator(knobs.withKnobs);

stories.add(
  'Display the hot search',
  withState({
    hotTags: MOCK_HOT_SEARCH.hotTags,
    hotTrades: MOCK_HOT_SEARCH.hotTrades,
    hotDrivers: MOCK_HOT_SEARCH.hotDrivers,
    recentSearch: MOCK_HOT_SEARCH.recentSearch,
    tradeResult: MOCK_SEARCH_RESULT.tradeResult,
    newsResult: MOCK_SEARCH_RESULT.newsResult,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        const handleRemoveRecentSearch = keyword => {
          const _clone = store.state.recentSearch.slice();

          _clone.splice(_clone.findIndex(obj => obj.keyword === keyword), 1);
          store.set({
            recentSearch: _clone,
          });
        };
        const handleRemoveAllRecentSearch = () => {
          store.set({
            recentSearch: [],
          });
        };

        return (
          <div style={WRAPPER_STYLES}>
            <div style={{ width: '400px' }}>
              <AnueSearchRealtimeResult
                hotTags={store.state.hotTags}
                hotTrades={store.state.hotTrades}
                hotDrivers={store.state.hotDrivers}
                recentSearch={store.state.recentSearch}
                tradeResult={store.state.tradeResult}
                newsResult={store.state.newsResult}
                driversResult={store.state.driversResult}
                onRecentSearchRowRemoveClick={handleRemoveRecentSearch}
                onRecentSearchRemoveAllClick={handleRemoveAllRecentSearch}
              />
            </div>
          </div>
        );
      })
    )
  )
);

stories.add(
  'Display the search result',
  withState({
    hotTags: MOCK_HOT_SEARCH.hotTags,
    hotTrades: MOCK_HOT_SEARCH.hotTrades,
    hotDrivers: MOCK_HOT_SEARCH.hotDrivers,
    recentSearch: MOCK_HOT_SEARCH.recentSearch,
    searchString: MOCK_SEARCH_RESULT.searchString,
    tradeResult: MOCK_SEARCH_RESULT.tradeResult,
    newsResult: MOCK_SEARCH_RESULT.newsResult,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        return (
          <div style={WRAPPER_STYLES}>
            <div style={{ width: '400px' }}>
              <AnueSearchRealtimeResult
                searchString="台積電"
                hotTags={store.state.hotTags}
                hotTrades={store.state.hotTrades}
                hotDrivers={store.state.hotDrivers}
                recentSearch={store.state.recentSearch}
                tradeResult={store.state.tradeResult}
                newsResult={store.state.newsResult}
                driversResult={store.state.driversResult}
              />
            </div>
          </div>
        );
      })
    )
  )
);

stories.add(
  'Display the hot search (New)',
  withState({
    hotTags: MOCK_HOT_SEARCH.hotTags,
    hotTrades: MOCK_HOT_SEARCH.hotTrades,
    hotDrivers: MOCK_HOT_SEARCH.hotDrivers,
    recentSearch: MOCK_HOT_SEARCH.recentSearch,
    tradeResult: MOCK_SEARCH_RESULT.tradeResult,
    newsResult: MOCK_SEARCH_RESULT.newsResult,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        const handleRemoveRecentSearch = keyword => {
          const _clone = store.state.recentSearch.slice();

          _clone.splice(_clone.findIndex(obj => obj.keyword === keyword), 1);
          store.set({
            recentSearch: _clone,
          });
        };
        const handleRemoveAllRecentSearch = () => {
          store.set({
            recentSearch: [],
          });
        };

        console.log('store.state.hotTrades: ', store.state.hotTrades);

        return (
          <div style={WRAPPER_STYLES}>
            <div style={{ width: '400px' }}>
              <AnueSearchRealtimeResult
                hotTags={store.state.hotTags}
                hotTrades={store.state.hotTrades}
                hotDrivers={store.state.hotDrivers}
                recentSearch={store.state.recentSearch}
                tradeResult={store.state.tradeResult}
                newsResult={store.state.newsResult}
                driversResult={store.state.driversResult}
                onRecentSearchRowRemoveClick={handleRemoveRecentSearch}
                onRecentSearchRemoveAllClick={handleRemoveAllRecentSearch}
                enableNewStyle
              />
            </div>
          </div>
        );
      })
    )
  )
);

stories.add(
  'Display the search result (New)',
  withState({
    hotTags: MOCK_HOT_SEARCH.hotTags,
    hotTrades: MOCK_HOT_SEARCH.hotTrades,
    hotDrivers: MOCK_HOT_SEARCH.hotDrivers,
    recentSearch: MOCK_HOT_SEARCH.recentSearch,
    searchString: MOCK_SEARCH_RESULT.searchString,
    tradeResult: MOCK_SEARCH_RESULT.tradeResult,
    newsResult: MOCK_SEARCH_RESULT.newsResult,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        return (
          <div style={WRAPPER_STYLES}>
            <div style={{ width: '400px' }}>
              <AnueSearchRealtimeResult
                searchString="台積電"
                hotTags={store.state.hotTags}
                hotTrades={store.state.hotTrades}
                hotDrivers={store.state.hotDrivers}
                recentSearch={store.state.recentSearch}
                tradeResult={store.state.tradeResult}
                newsResult={store.state.newsResult}
                driversResult={store.state.driversResult}
                enableNewStyle
              />
            </div>
          </div>
        );
      })
    )
  )
);
