import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';
import Dialog, { THEME } from '../Dialog';
import DialogButton from '../DialogButton';
import defaultNotes from './Dialog.md';
import Graphql1 from './graphic-1.svg';
import Graphql2 from './graphic-2.svg';
import styles from './stories.style.scss';

const stories = storiesOf('Dialog', module);

stories.addDecorator(knobs.withKnobs);
stories.addDecorator(story => <div className={styles.wrapper}>{story()}</div>);

stories.add(
  '新版首頁上線前預告',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        const footer = (
          <div className={styles['lecture-footer']}>
            <DialogButton
              theme={THEME.ANUE}
              onClick={() => {
                store.set({ isOpen: false });
              }}
            >
              我知道了
            </DialogButton>
            <DialogButton
              theme={THEME.ANUE}
              active
              onClick={() => {
                window.location.href = 'https://www.beta.cnyes.cool/home';
              }}
            >
              搶先體驗
            </DialogButton>
          </div>
        );

        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={400}
              height={300}
              visible={store.state.isOpen}
              onClose={() => store.set({ isOpen: false })}
              footer={footer}
            >
              <div className={styles['post-content']}>
                <img src={Graphql1} alt="graphic" />
                <p>
                  <strong>”鉅亨首頁即將全新改版，敬請期待！”</strong>
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);

stories.add(
  '全新首頁上線',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={400}
              height={372}
              visible={store.state.isOpen}
              onClose={() => store.set({ isOpen: false })}
              needClose={false}
            >
              <div className={styles['post-content']}>
                <img src={Graphql2} alt="graphic" />
                <p>
                  <strong>”全新首頁上線，立即體驗！”</strong>
                </p>
                <p>
                  <small>
                    <strong>想要切換舊首頁，請點擊右上角「使用舊版首頁」</strong>
                  </small>
                </p>
                <p>
                  <small>
                    ※小提醒，舊首頁即將於<span>yyyy/mm/dd</span>正式下線{' '}
                  </small>
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);

stories.add(
  '公告講座未帶圖片',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={500}
              height={263}
              styleType={THEME.NORMAL}
              visible={store.state.isOpen}
              needClose={false}
              onClose={() => store.set({ isOpen: false })}
            >
              <div className={styles['lecture-content']}>
                <h4>如何在高波動的虛擬貨幣市場中，穩健投資？兩大分析師帶你一次掌握趨勢策略！</h4>
                <p>
                  2021 上半年迎來虛擬貨幣 (也稱加密貨幣) 市場的大牛市，特斯拉、灰度、微策略、Nexon
                  等等眾多機構紛紛進場，貨幣市場受到前所未有的關注！
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);

stories.add(
  '公告講座帶圖片',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        const footer = (
          <div className={styles['lecture-footer']}>
            <DialogButton
              theme={THEME.NORMAL}
              onClick={() => {
                store.set({ isOpen: false });
              }}
            >
              我知道了
            </DialogButton>
            <DialogButton
              theme={THEME.NORMAL}
              active
              onClick={() => {
                window.location.href = 'https://www.cnyes.com';
              }}
            >
              造訪網站
            </DialogButton>
          </div>
        );

        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={500}
              height={263}
              styleType={THEME.NORMAL}
              visible={store.state.isOpen}
              needClose={false}
              onClose={() => store.set({ isOpen: false })}
              footer={footer}
            >
              <div className={styles['lecture-content']}>
                <img src="https://via.placeholder.com/468x219.png" className={styles.cover} alt="Cover" />
                <h4>如何在高波動的虛擬貨幣市場中，穩健投資？兩大分析師帶你一次掌握趨勢策略！</h4>
                <p>
                  2021 上半年迎來虛擬貨幣 (也稱加密貨幣) 市場的大牛市，特斯拉、灰度、微策略、Nexon
                  等等眾多機構紛紛進場，貨幣市場受到前所未有的關注！
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);

stories.add(
  '點擊視窗外區塊不可關閉',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        const footer = (
          <DialogButton
            theme={THEME.ANUE}
            active
            onClick={() => {
              window.location.href = 'https://www.beta.cnyes.cool/home';
            }}
          >
            搶先體驗
          </DialogButton>
        );

        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={400}
              height={300}
              visible={store.state.isOpen}
              maskClosable={false}
              onClose={() => store.set({ isOpen: false })}
              footer={footer}
            >
              <div className={styles['post-content']}>
                <img src={Graphql1} alt="graphic" />
                <p>
                  <strong>”鉅亨首頁即將全新改版，敬請期待！”</strong>
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);

stories.add(
  '帶有標題和關閉按鈕',
  withNotes(defaultNotes)(
    withState({ isOpen: false })(
      withInfo()(({ store }) => {
        const footer = (
          <DialogButton
            theme={THEME.ANUE}
            active
            onClick={() => {
              window.location.href = 'https://www.beta.cnyes.cool/home';
            }}
          >
            搶先體驗
          </DialogButton>
        );

        return (
          <div>
            <button className={styles.button} onClick={() => store.set({ isOpen: true })}>
              彈出視窗
            </button>
            <Dialog
              width={400}
              height={300}
              visible={store.state.isOpen}
              maskClosable={false}
              onClose={() => store.set({ isOpen: false })}
              title="全新改版"
              needClose
              footer={footer}
            >
              <div className={styles['post-content']}>
                <img src={Graphql1} alt="graphic" />
                <p>
                  <strong>”鉅亨首頁即將全新改版，敬請期待！”</strong>
                </p>
              </div>
            </Dialog>
          </div>
        );
      })
    )
  )
);
