import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import SmartBanner from '../SmartBanner';

const windowUserAgent =
  'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36';
const iosUserAgent =
  'Mozilla/5.0 (iPhone; CPU iPhone OS 10_3_1 like Mac OS X) AppleWebKit/603.1.30 (KHTML, like Gecko) Version/10.0 Mobile/14E304 Safari/602.1Mozilla/5.0 (iPhone; CPU iPhone OS 10_3_1 like Mac OS X) AppleWebKit/603.1.30 (KHTML, like Gecko) Version/10.0 Mobile/14E304 Safari/602.1';
const androidUserAgent =
  'Mozilla/5.0 (Linux; Android 11; Pixel 5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.91 Mobile Safari/537.36';
const mockCallOpen = jest.fn();

Object.defineProperty(
  global.window.navigator,
  'userAgent',
  (value => ({
    get() {
      return value;
    },
    set(v) {
      // eslint-disable-next-line no-param-reassign
      value = v;
    },
  }))(global.navigator.userAgent)
);

global.window.open = mockCallOpen;

function changeUserAgent(userAgent) {
  global.window.navigator.userAgent = userAgent;
}

describe('SmartBanner flow', () => {
  let SmartBannerElement;

  beforeEach(() => {
    jest.resetModules();
    document.body.innerHTML = `
      <meta name="apple-itunes-app" content="app-id=1071014509" />
      <meta name="google-play-app" content="app-id=com.cnyes.android" />
    `;
    SmartBannerElement = () => {
      return mount(<SmartBanner />);
    };
  });

  it('ios banner show', () => {
    changeUserAgent(iosUserAgent);
    expect(SmartBannerElement().find('.smart-banner-download')).toHaveLength(1);
  });

  it('window banner hide', () => {
    changeUserAgent(windowUserAgent);
    expect(SmartBannerElement().find('.smart-banner')).toHaveLength(0);
  });

  it('android banner show', () => {
    changeUserAgent(androidUserAgent);
    expect(SmartBannerElement().find('.smart-banner-download')).toHaveLength(1);
  });

  it('banner snapshots check', () => {
    expect(toJson(SmartBannerElement())).toMatchSnapshot();
  });

  it('event downloadHandler btn test', () => {
    SmartBannerElement()
      .find('.smart-banner-download')
      .simulate('click');
    expect(mockCallOpen.mock.calls.length).toEqual(1);
  });

  it('expired banner hide', () => {
    expect(SmartBannerElement().find('.smart-banner')).toHaveLength(0);
  });

  it('banner hide snapshots check', () => {
    expect(toJson(SmartBannerElement())).toMatchSnapshot();
  });
});
