/* eslint-disable no-unused-expressions */
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import gaDataset from '../../utils/gaDataset';
import SwitchIcon from '../../assets/icon-trad.svg';
import styles from './SwitchVersionButton.scss';

export const NEW_VERSION = 'new';
export const OLD_VERSION = 'old';

const cx = classNames.bind(styles);

export default class SwitchVersionButton extends React.PureComponent {
  static propTypes = {
    className: PropTypes.string,
    iconClassName: PropTypes.string,
    textClassName: PropTypes.string,
    defaultVersion: PropTypes.string,
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
    onSwitchVersion: PropTypes.func,
    divider: PropTypes.oneOf(['left', 'none', 'right']),
  };

  static defaultProps = {
    className: '',
    iconClassName: '',
    textClassName: '',
    defaultVersion: NEW_VERSION,
    dataPrefix: ['data-global-ga'],
    onSwitchVersion: () => {},
    divider: 'left',
  };

  state = { isLoading: false };

  switchVersionHandler = () => {
    const { onSwitchVersion, defaultVersion } = this.props;

    this.setState({ isLoading: true });
    onSwitchVersion && onSwitchVersion(defaultVersion);
  };

  // 用 CSS 撰寫出來的讀取進度
  // https://loading.io/css/
  ringLoading = (
    <div className={cx('lds-ring')}>
      <div />
      <div />
      <div />
      <div />
    </div>
  );

  render() {
    const { defaultVersion, divider, className, iconClassName, textClassName, dataPrefix } = this.props;
    const gaEventLabel = defaultVersion === NEW_VERSION ? 'version_new' : 'version_old';

    const dividerSettings = {
      'divider-right': divider === 'right',
      'divider-left': divider === 'left',
    };

    const style = className.length > 0 ? className : cx('switch-wrapper', dividerSettings);
    const iconStyle = iconClassName.length > 0 ? iconClassName : cx('icon');
    const buttonStyle = textClassName.length > 0 ? textClassName : cx('switch-button');

    return (
      <div className={style}>
        <img src={SwitchIcon} className={iconStyle} alt="Switch" />
        <div
          className={buttonStyle}
          {...gaDataset({ dataPrefix, category: 'Header', action: 'VerSwitch', label: gaEventLabel })}
          onClick={this.switchVersionHandler}
        >
          {this.state.isLoading ? this.ringLoading : '切換'}
        </div>
      </div>
    );
  }
}
