/**
 * 執行 `yarn build:common` 建置靜態頁面所需要使用的 Header 檔案
 * 成功執行後會在 `src/static/dist/common` 目錄下看到 .Net 專案各個 header 目錄
 * .Net 團隊只需要將該目錄內的所有內容直接複製到專案目錄下覆蓋即可
 */

import React from 'react';
import ReactDOM from 'react-dom/server';
import Header from './components/Header/StaticHeader';
import Footer from './components/Footer/Footer';
import AllConfig from './components/Header/config/AllConfig';
import headerConfig from './components/AnueNavigator/config/navs.json';
// import Crypto from './components/Crypto/Crypto';
import './styles/static.scss';

const allHeaders = Object.keys(AllConfig).reduce((previous, keyName) => {
  const { name } = AllConfig[keyName];

  const headerHTML = ReactDOM.renderToString(
    <Header navs={headerConfig} channelName={name} apiEnv="prod" location={{ pathname: '/' }} />
  );
  const headerJavascript = `<script type="text/javascript" src="/inc/CommonWebControls/html/${keyName}Header/header.js?t=${Date.now()}"></script>`;
  const headerCss = `<link href="/inc/CommonWebControls/html/${keyName}Header/header.css?t=${Date.now()}" rel="stylesheet" type="text/css" />`;

  // static crypto
  // const cryptoHtml = ReactDOM.renderToString(<Crypto />);

  return {
    ...previous,
    [`/common/${keyName}Header`]: `<header id="anue-header">${headerHTML}${headerJavascript}${headerCss}</header>`,
    // '/common/crypto': `<div id="crypto">${cryptoHtml}</div>`,
  };
}, {});

// https://www.npmjs.com/package/static-site-generator-webpack-plugin
module.exports = function render() {
  return {
    ...allHeaders,
    '/common/footer': ReactDOM.renderToString(<Footer now={Date.now()} />),
  };
};
